@@ -64,6 +64,7 @@ namespace Breeze
         connect( _scrollBarAddLineButtons, SIGNAL(currentIndexChanged(int)), SLOT(updateChanged()) );
         connect( _scrollBarSubLineButtons, SIGNAL(currentIndexChanged(int)), SLOT(updateChanged()) );
         connect( _windowDragMode, SIGNAL(currentIndexChanged(int)), SLOT(updateChanged()) );
+        connect( _menuOpacity, SIGNAL(valueChanged(int)), SLOT(updateChanged()) );
 
     }
 
@@ -84,7 +85,8 @@ namespace Breeze
         StyleConfigData::setScrollBarSubLineButtons( _scrollBarSubLineButtons->currentIndex() );
         StyleConfigData::setAnimationsEnabled( _animationsEnabled->isChecked() );
         StyleConfigData::setAnimationsDuration( _animationsDuration->value() );
-        StyleConfigData::setWindowDragMode( _windowDragMode->currentIndex()  );
+        StyleConfigData::setWindowDragMode( _windowDragMode->currentIndex() );
+        StyleConfigData::setMenuOpacity( _menuOpacity->value() );
 
         #if BREEZE_USE_KDE4
         StyleConfigData::self()->writeConfig();
@@ -95,7 +97,7 @@ namespace Breeze
         Kdelibs4Migration migration;
         const QString kde4ConfigDirPath = migration.saveLocation("config");
 
-        QScopedPointer<KConfig> kde4Config(StyleConfigData::self()->config()->copyTo(kde4ConfigDirPath+"/breezerc", 0));
+        QScopedPointer<KConfig> kde4Config(StyleConfigData::self()->config()->copyTo(kde4ConfigDirPath+"/breezerc", nullptr));
         kde4Config->sync();
         #endif
 
@@ -147,6 +149,7 @@ namespace Breeze
         else if( _animationsEnabled->isChecked() != StyleConfigData::animationsEnabled() ) modified = true;
         else if( _animationsDuration->value() != StyleConfigData::animationsDuration() ) modified = true;
         else if( _windowDragMode->currentIndex() != StyleConfigData::windowDragMode() ) modified = true;
+        else if( _menuOpacity->value() != StyleConfigData::menuOpacity() ) modified = true;
 
         emit changed(modified);
 
@@ -171,6 +174,7 @@ namespace Breeze
         _animationsEnabled->setChecked( StyleConfigData::animationsEnabled() );
         _animationsDuration->setValue( StyleConfigData::animationsDuration() );
         _windowDragMode->setCurrentIndex( StyleConfigData::windowDragMode() );
+        _menuOpacity->setValue( StyleConfigData::menuOpacity() );
 
     }
 
